layouttools.SpacingIndication
=============================

.. abjad-lineage:: abjad.tools.layouttools.SpacingIndication.SpacingIndication

.. autoclass:: abjad.tools.layouttools.SpacingIndication.SpacingIndication

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.normalized_spacing_duration
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.proportional_notation_duration
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.tempo_indication
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.__eq__
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.__format__
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.__hash__
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.__ne__
      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.normalized_spacing_duration
   :noindex:

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.proportional_notation_duration
   :noindex:

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.tempo_indication
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.__eq__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.__format__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.__hash__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.__ne__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.__repr__
   :noindex:
